@@ -10,7 +10,7 @@ use IO::Socket;
 use IO::Socket::SSL;
 use Time::Crontab;
 
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.09'; # VERSION
 
 sub new {
     my $class = shift;
@@ -96,6 +96,7 @@ sub _parent {
     };
 
     srand();
+    my @lines;
 
     eval {
         while ( my $line = $self->{socket}->getline ) {
@@ -128,7 +129,17 @@ sub _parent {
                 }
             }
 
-            $delegate->($line);
+            shift @lines while ( @lines > 10 );
+            my $now = time();
+
+            unless ( grep { $_->{line} eq $line and $_->{time} + 1 > $now } @lines ) {
+                $delegate->($line);
+            }
+            else {
+                print "### Skipped repeated line: $line\n";
+            }
+
+            push @lines, { line => $line, time => $now };
         }
     };
     warn "$@\n";
@@ -494,7 +505,7 @@ Bot::IRC - Yet Another IRC Bot
 
 =head1 VERSION
 
-version 1.08
+version 1.09
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bot-IRC.svg)](https://travis-ci.org/gryphonshafer/Bot-IRC)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bot-IRC/badge.png)](https://coveralls.io/r/gryphonshafer/Bot-IRC)
